@@ -1,15 +1,14 @@
 package Net::SAML2::Protocol::ArtifactResolve;
 use Moose;
-use MooseX::Types::Moose qw/ Str /;
 use MooseX::Types::URI qw/ Uri /;
 
 with 'Net::SAML2::Role::ProtocolMessage';
 
 
 
-has 'issuer'      => (isa => Str, is => 'ro', required => 1);
-has 'destination' => (isa => Str, is => 'ro', required => 1);
-has 'artifact'    => (isa => Str, is => 'ro', required => 1);
+has 'issuer'      => (isa => 'Str', is => 'ro', required => 1);
+has 'destination' => (isa => 'Str', is => 'ro', required => 1);
+has 'artifact'    => (isa => 'Str', is => 'ro', required => 1);
 
 
 sub as_xml {
@@ -53,7 +52,7 @@ Net::SAML2::Protocol::ArtifactResolve
 
 =head1 VERSION
 
-version 0.25
+version 0.28
 
 =head1 SYNOPSIS
 
@@ -107,7 +106,7 @@ This software is copyright (c) 2020 by Chris Andrews and Others; in detail:
   Copyright 2010-2011  Chris Andrews
             2012       Peter Marschall
             2017       Alessandro Ranellucci
-            2020       Timothy Legge
+            2020       Timothy Legge, Wesley Schwengle
 
 
 This is free software; you can redistribute it and/or modify it under
